@@ -11,4 +11,8 @@ __all__ = ["motd",
            "manage",
            "event",
            "sync",
-           "updateui"]
+           "updateui",
+           "handoff",
+           "register_samplers",
+           "alert",
+           "sample"]
